cloudns
    * ``auth_id`` Specify user id for authentication

    * ``auth_subid`` Specify subuser id for authentication

    * ``auth_subuser`` Specify subuser name for authentication

    * ``auth_password`` Specify password for authentication

    * ``weight`` Specify the srv record weight

    * ``port`` Specify the srv record port
